﻿using C1.WPF.Grid;
using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace ImageConditional
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            Random rnd = new Random();
            for (int i = 0; i < 50; i++)
            {
                flexGrid.Rows.Add(new GridRow());
                flexGrid[i, 0] = $"Item {i}";
                flexGrid[i, 1] = rnd.Next(0, 1000);
            }

            //assigning custom CellFactory
            flexGrid.CellFactory = new CustomCellFactory();
        }
    }

    class CustomCellFactory : GridCellFactory
    {
        public override FrameworkElement CreateCellContent(GridCellType cellType, GridCellRange range, object cellContentType)
        {
            //let grid create the FrameworkElement
            var element = base.CreateCellContent(cellType, range, cellContentType);

            //if column needs to show image
            if (cellType == GridCellType.Cell && Grid.Columns[range.Column].ColumnName.Equals("Value"))
            {
                //show text for cells
                var textBlock = (element as Grid).Children[0] as TextBlock;
                var cellValue = (int)Grid[range.Row, range.Column];
                textBlock.Text = cellValue.ToString();

                //show image for some cells
                if (cellValue > 500)
                {
                    var bitmap = new BitmapImage(new Uri("pack://application:,,,/Resources/sample.png"));
                    var image = (element as Grid).Children[1] as Image;
                    image.Source = bitmap;
                    image.Height = bitmap.Height;
                    image.Width = bitmap.Width;
                }
            }

            //return FrameworkElement
            return element;
        }
    }
}
